@@ -12,6 +12,7 @@ from PIL import Image
 from pypdfium2 import PdfPage
 
 from docling.backend.pdf_backend import PdfDocumentBackend, PdfPageBackend
+from docling.datamodel.backend_options import PdfBackendOptions
 from docling.datamodel.base_models import Size
 from docling.utils.locks import pypdfium2_lock
 
@@ -30,13 +31,21 @@ class DoclingParseV4PageBackend(PdfPageBackend):
         page_no: int,
         create_words: bool = True,
         create_textlines: bool = True,
+        keep_chars: bool = False,
+        keep_lines: bool = False,
+        keep_images: bool = True,
     ):
         self._ppage = page_obj
         self._dp_doc = dp_doc
         self._page_no = page_no
+
         self._create_words = create_words
         self._create_textlines = create_textlines
 
+        self._keep_chars = keep_chars
+        self._keep_lines = keep_lines
+        self._keep_images = keep_images
+
         self._dpage: Optional[SegmentedPdfPage] = None
         self._unloaded = False
         self.valid = (self._ppage is not None) and (self._dp_doc is not None)
@@ -47,8 +56,12 @@ class DoclingParseV4PageBackend(PdfPageBackend):
 
         seg_page = self._dp_doc.get_page(
             self._page_no + 1,
+            keep_chars=self._keep_chars,
+            keep_lines=self._keep_lines,
+            keep_bitmaps=self._keep_images,
             create_words=self._create_words,
             create_textlines=self._create_textlines,
+            enforce_same_font=True,
         )
 
         # In Docling, all TextCell instances are expected with top-left origin.
@@ -177,13 +190,23 @@ class DoclingParseV4PageBackend(PdfPageBackend):
 
 
 class DoclingParseV4DocumentBackend(PdfDocumentBackend):
-    def __init__(self, in_doc: "InputDocument", path_or_stream: Union[BytesIO, Path]):
-        super().__init__(in_doc, path_or_stream)
+    def __init__(
+        self,
+        in_doc: "InputDocument",
+        path_or_stream: Union[BytesIO, Path],
+        options: PdfBackendOptions = PdfBackendOptions(),
+    ):
+        super().__init__(in_doc, path_or_stream, options)
 
+        password = (
+            self.options.password.get_secret_value() if self.options.password else None
+        )
         with pypdfium2_lock:
-            self._pdoc = pdfium.PdfDocument(self.path_or_stream)
+            self._pdoc = pdfium.PdfDocument(self.path_or_stream, password=password)
         self.parser = DoclingPdfParser(loglevel="fatal")
-        self.dp_doc: PdfDocument = self.parser.load(path_or_stream=self.path_or_stream)
+        self.dp_doc: PdfDocument = self.parser.load(
+            path_or_stream=self.path_or_stream, password=password
+        )
         success = self.dp_doc is not None
 
         if not success:
