@@ -117,6 +117,10 @@ class TesseractOcrCliModel(BaseOcrModel):
             cmd.append("--tessdata-dir")
             cmd.append(self.options.path)
 
+        # Add PSM option if specified in the configuration
+        if self.options.psm is not None:
+            cmd.extend(["--psm", str(self.options.psm)])
+
         cmd += [ifilename, "stdout", "tsv"]
         _log.info("command: {}".format(" ".join(cmd)))
 
